@@ -10,13 +10,13 @@ from pathlib import Path
 from random import random
 
 import requests
+from tqdm import tqdm
 
-from ultralytics.yolo.utils import (DEFAULT_CFG_DICT, ENVIRONMENT, LOGGER, RANK, SETTINGS, TESTS_RUNNING, TryExcept,
-                                    __version__, colorstr, emojis, get_git_origin_url, is_colab, is_git_dir,
-                                    is_pip_package)
-from ultralytics.yolo.utils.checks import check_online
+from ultralytics.yolo.utils import (DEFAULT_CFG_DICT, ENVIRONMENT, LOGGER, ONLINE, RANK, SETTINGS, TESTS_RUNNING,
+                                    TQDM_BAR_FORMAT, TryExcept, __version__, colorstr, emojis, get_git_origin_url,
+                                    is_colab, is_git_dir, is_pip_package)
 
-PREFIX = colorstr('Ultralytics: ')
+PREFIX = colorstr('Ultralytics HUB: ')
 HELP_MSG = 'If this issue persists please visit https://github.com/ultralytics/hub/issues for assistance.'
 HUB_API_ROOT = os.environ.get('ULTRALYTICS_HUB_API', 'https://api.ultralytics.com')
 
@@ -60,7 +60,6 @@ def request_with_credentials(url: str) -> any:
     return output.eval_js('_hub_tmp')
 
 
-# Deprecated TODO: eliminate this function?
 def split_key(key=''):
     """
     Verify and split a 'api_key[sep]model_id' string, sep is one of '.' or '_'
@@ -84,36 +83,61 @@ def split_key(key=''):
     return api_key, model_id
 
 
-def smart_request(*args, retry=3, timeout=30, thread=True, code=-1, method='post', verbose=True, **kwargs):
+def requests_with_progress(method, url, **kwargs):
+    """
+    Make an HTTP request using the specified method and URL, with an optional progress bar.
+
+    Args:
+        method (str): The HTTP method to use (e.g. 'GET', 'POST').
+        url (str): The URL to send the request to.
+        progress (bool, optional): Whether to display a progress bar. Defaults to False.
+        **kwargs: Additional keyword arguments to pass to the underlying `requests.request` function.
+
+    Returns:
+        requests.Response: The response from the HTTP request.
+
+    """
+    progress = kwargs.pop('progress', False)
+    if not progress:
+        return requests.request(method, url, **kwargs)
+    response = requests.request(method, url, stream=True, **kwargs)
+    total = int(response.headers.get('content-length', 0))  # total size
+    pbar = tqdm(total=total, unit='B', unit_scale=True, unit_divisor=1024, bar_format=TQDM_BAR_FORMAT)
+    for data in response.iter_content(chunk_size=1024):
+        pbar.update(len(data))
+    pbar.close()
+    return response
+
+
+def smart_request(method, url, retry=3, timeout=30, thread=True, code=-1, verbose=True, progress=False, **kwargs):
     """
     Makes an HTTP request using the 'requests' library, with exponential backoff retries up to a specified timeout.
 
     Args:
-        *args: Positional arguments to be passed to the requests function specified in method.
+        method (str): The HTTP method to use for the request. Choices are 'post' and 'get'.
+        url (str): The URL to make the request to.
         retry (int, optional): Number of retries to attempt before giving up. Default is 3.
         timeout (int, optional): Timeout in seconds after which the function will give up retrying. Default is 30.
         thread (bool, optional): Whether to execute the request in a separate daemon thread. Default is True.
         code (int, optional): An identifier for the request, used for logging purposes. Default is -1.
-        method (str, optional): The HTTP method to use for the request. Choices are 'post' and 'get'. Default is 'post'.
         verbose (bool, optional): A flag to determine whether to print out to console or not. Default is True.
+        progress (bool, optional): Whether to show a progress bar during the request. Default is False.
         **kwargs: Keyword arguments to be passed to the requests function specified in method.
 
     Returns:
         requests.Response: The HTTP response object. If the request is executed in a separate thread, returns None.
+
     """
     retry_codes = (408, 500)  # retry only these codes
 
     @TryExcept(verbose=verbose)
-    def func(*func_args, **func_kwargs):
+    def func(func_method, func_url, **func_kwargs):
         r = None  # response
         t0 = time.time()  # initial time for timer
         for i in range(retry + 1):
             if (time.time() - t0) > timeout:
                 break
-            if method == 'post':
-                r = requests.post(*func_args, **func_kwargs)  # i.e. post(url, data, json, files)
-            elif method == 'get':
-                r = requests.get(*func_args, **func_kwargs)  # i.e. get(url, data, json, files)
+            r = requests_with_progress(func_method, func_url, **func_kwargs)  # i.e. get(url, data, json, files)
             if r.status_code == 200:
                 break
             try:
@@ -134,6 +158,8 @@ def smart_request(*args, retry=3, timeout=30, thread=True, code=-1, method='post
             time.sleep(2 ** i)  # exponential standoff
         return r
 
+    args = method, url
+    kwargs['progress'] = progress
     if thread:
         threading.Thread(target=func, args=args, kwargs=kwargs, daemon=True).start()
     else:
@@ -157,8 +183,8 @@ class Traces:
         self.enabled = \
             SETTINGS['sync'] and \
             RANK in {-1, 0} and \
-            check_online() and \
             not TESTS_RUNNING and \
+            ONLINE and \
             (is_pip_package() or get_git_origin_url() == 'https://github.com/ultralytics/ultralytics.git')
 
     def __call__(self, cfg, all_keys=False, traces_sample_rate=1.0):
@@ -182,13 +208,7 @@ class Traces:
             trace = {'uuid': SETTINGS['uuid'], 'cfg': cfg, 'metadata': self.metadata}
 
             # Send a request to the HUB API to sync analytics
-            smart_request(f'{HUB_API_ROOT}/v1/usage/anonymous',
-                          json=trace,
-                          headers=None,
-                          code=3,
-                          retry=0,
-                          timeout=1.0,
-                          verbose=False)
+            smart_request('post', f'{HUB_API_ROOT}/v1/usage/anonymous', json=trace, code=3, retry=0, verbose=False)
 
 
 # Run below code on hub/utils init -------------------------------------------------------------------------------------
