@@ -2,14 +2,14 @@
 
 from ultralytics.yolo.data import build_classification_dataloader
 from ultralytics.yolo.engine.validator import BaseValidator
-from ultralytics.yolo.utils import DEFAULT_CFG
+from ultralytics.yolo.utils import DEFAULT_CFG, LOGGER
 from ultralytics.yolo.utils.metrics import ClassifyMetrics
 
 
 class ClassificationValidator(BaseValidator):
 
-    def __init__(self, dataloader=None, save_dir=None, pbar=None, logger=None, args=None):
-        super().__init__(dataloader, save_dir, pbar, logger, args)
+    def __init__(self, dataloader=None, save_dir=None, pbar=None, args=None):
+        super().__init__(dataloader, save_dir, pbar, args)
         self.args.task = 'classify'
         self.metrics = ClassifyMetrics()
 
@@ -21,14 +21,18 @@ class ClassificationValidator(BaseValidator):
         self.targets = []
 
     def preprocess(self, batch):
-        batch["img"] = batch["img"].to(self.device, non_blocking=True)
-        batch["img"] = batch["img"].half() if self.args.half else batch["img"].float()
-        batch["cls"] = batch["cls"].to(self.device)
+        batch['img'] = batch['img'].to(self.device, non_blocking=True)
+        batch['img'] = batch['img'].half() if self.args.half else batch['img'].float()
+        batch['cls'] = batch['cls'].to(self.device)
         return batch
 
     def update_metrics(self, preds, batch):
-        self.pred.append(preds.argsort(1, descending=True)[:, :5])
-        self.targets.append(batch["cls"])
+        n5 = min(len(self.model.names), 5)
+        self.pred.append(preds.argsort(1, descending=True)[:, :n5])
+        self.targets.append(batch['cls'])
+
+    def finalize_metrics(self, *args, **kwargs):
+        self.metrics.speed = self.speed
 
     def get_stats(self):
         self.metrics.process(self.targets, self.pred)
@@ -42,12 +46,12 @@ class ClassificationValidator(BaseValidator):
 
     def print_results(self):
         pf = '%22s' + '%11.3g' * len(self.metrics.keys)  # print format
-        self.logger.info(pf % ("all", self.metrics.top1, self.metrics.top5))
+        LOGGER.info(pf % ('all', self.metrics.top1, self.metrics.top5))
 
 
 def val(cfg=DEFAULT_CFG, use_python=False):
-    model = cfg.model or "yolov8n-cls.pt"  # or "resnet18"
-    data = cfg.data or "mnist160"
+    model = cfg.model or 'yolov8n-cls.pt'  # or "resnet18"
+    data = cfg.data or 'mnist160'
 
     args = dict(model=model, data=data)
     if use_python:
@@ -58,5 +62,5 @@ def val(cfg=DEFAULT_CFG, use_python=False):
         validator(model=args['model'])
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     val()
